@@ -476,7 +476,6 @@ DebugClientParser::parseSelf( const char * tok,
                               DebugViewPtr & debug_view )
 {
     const char * start = tok;
-    char * next;
 
     while ( *tok != '\0' && *tok == '(' ) ++tok;
     while ( *tok != '\0' && *tok == ' ' ) ++tok;
@@ -492,6 +491,31 @@ DebugClientParser::parseSelf( const char * tok,
     }
 
     ++tok; // skip side
+    while ( *tok != '\0' && *tok == ' ' ) ++tok; // skip space
+
+    //
+    // coach
+    //
+    if ( *tok == 'c' )
+    {
+        M_side = side;
+        M_unum = 12;
+
+        boost::shared_ptr< DebugViewData::SelfT > coach( new DebugViewData::SelfT( side ) );
+        debug_view->setSelf( coach );
+
+        // skip this token
+        while ( *tok != '\0' && *tok != ')' ) ++tok;
+        while ( *tok != '\0' && ( *tok == ' ' || *tok == ')' ) ) ++tok;
+
+        return tok - start;
+    }
+
+    //
+    // player
+    //
+
+    char * next;
 
     const long unum = std::strtol( tok, &next, 10 );
     if ( unum == LONG_MIN || unum == LONG_MAX ) return 0;
