@@ -12,7 +12,7 @@
 
  This code is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
- the Free Software Foundation; either version 2, or (at your option)
+ the Free Software Foundation; either version 3, or (at your option)
  any later version.
 
  This code is distributed in the hope that it will be useful,
@@ -76,25 +76,6 @@ public:
     static const boost::int32_t LEVEL_31 = 0x40000000;
     static const boost::int32_t LEVEL_32 = 0x80000000;
     static const boost::int32_t LEVEL_ANY = 0xffffffff;
-//     enum Type {
-//         LEVEL_0 = 0x0000,
-//         LEVEL_1 = 0x0001,
-//         LEVEL_2 = 0x0002,
-//         LEVEL_3 = 0x0004,
-//         LEVEL_4 = 0x0008,
-//         LEVEL_5 = 0x0010,
-//         LEVEL_6 = 0x0020,
-//         LEVEL_7 = 0x0040,
-//         LEVEL_8 = 0x0080,
-//         LEVEL_9 = 0x0100,
-//         LEVEL_10 = 0x0200,
-//         LEVEL_11 = 0x0400,
-//         LEVEL_12 = 0x0800,
-//         LEVEL_13 = 0x1000,
-//         LEVEL_14 = 0x2000,
-//         LEVEL_15 = 0x4000,
-//         LEVEL_16 = 0x8000,
-//     };
 
     struct TextT {
         boost::int32_t level_;
@@ -132,6 +113,23 @@ public:
             , y2_( 0.0 )
           { }
     };
+    struct ArcT {
+        boost::int32_t level_;
+        double x_;
+        double y_;
+        double r_;
+        double start_angle_;
+        double span_angle_;
+        std::string color_;
+        ArcT()
+            : level_( 0 )
+            , x_( 0.0 )
+            , y_( 0.0 )
+            , r_( 0.0 )
+            , start_angle_( 0.0 )
+            , span_angle_( 0.0 )
+          { }
+    };
     struct CircleT {
         boost::int32_t level_;
         double x_;
@@ -179,6 +177,25 @@ public:
             , height_( 0.0 )
           { }
     };
+   struct SectorT {
+        boost::int32_t level_;
+        double x_;
+        double y_;
+        double min_r_;
+        double max_r_;
+        double start_angle_;
+        double span_angle_;
+        std::string color_;
+        SectorT()
+            : level_( 0 )
+            , x_( 0.0 )
+            , y_( 0.0 )
+            , min_r_( 0.0 )
+            , max_r_( 0.0 )
+            , start_angle_( 0.0 )
+            , span_angle_( 0.0 )
+          { }
+    };
     struct MessageT {
         boost::int32_t level_;
         double x_;
@@ -197,20 +214,28 @@ public:
     Line := <Time> <Level> <Type> <Content>
     Time := integer value
     Level := integer value
-    Type := {T|p|l|c|m}
-        T : text
+    Type := {M|p|l|c|C|t|T|r|R|m}
+        M : log message text
         p : point
         l: line
+        a: arc
         c: circle
+        C: filled circle
         t: triangle
+        T: filled triangle
         r: rectangle
+        R: filled rectangle
+        s: sector
+        S: filled sector
         m: message;
     Text := <Str>
     Point := <x:Real> <y:Real>[ <Color>]
     Line := <x1:Real> <y1:Real> <x2:Real> <y2:Real>[ <Color>]
+    Arc := <x:Real> <y:Real> <r:Real> <angle:Real> <span:Real>[ <Color>]
     Circle := <x:Real> <y:Real> <r:Real>[ <Color>]
     Triangle := <x1:Real> <y1:Real> <x2:Real> <y2:Real> <x3:Real> <y3:Real>[ <Color>]
     Rectangle := <leftX:Real> <topY:Real> <width:Real> <height:Real>[ <Color>]
+    Sector := <x:Real> <y:Real> <minRadius:Real> <maxRadius:Real> <angle:Real> <span:Real>[ <Color>]
     Message := <x:Real> <y:Real>[ (c <Color>)] <Str>
     **********************************************************/
 
@@ -219,37 +244,43 @@ public:
 
     typedef std::list< PointT > PointCont;
     typedef std::list< LineT > LineCont;
+    typedef std::list< ArcT > ArcCont;
     typedef std::list< CircleT > CircleCont;
     typedef std::list< TriangleT > TriangleCont;
     typedef std::list< RectT > RectCont;
+    typedef std::list< SectorT > SectorCont;
     typedef std::list< MessageT > MessageCont;
 private:
-    long M_cycle;
+    int M_cycle;
 
-    //! normal message that is append to debug message box.
+    //! normal message append to debug message box.
     TextCont M_text_cont;
 
-    // key: level, value: data set for it.
     PointCont M_point_cont;
     LineCont M_line_cont;
+    ArcCont M_arc_cont;
     CircleCont M_circle_cont;
+    CircleCont M_filled_circle_cont;
     TriangleCont M_triangle_cont;
+    TriangleCont M_filled_triangle_cont;
     RectCont M_rect_cont;
+    RectCont M_filled_rect_cont;
+    SectorCont M_sector_cont;
+    SectorCont M_filled_sector_cont;
     MessageCont M_message_cont;
 
 public:
     explicit
-    DebugLogData( const long & cycle )
+    DebugLogData( const int cycle )
         : M_cycle( cycle )
       { }
 
-    void setCycle( const long & cycle )
+    void setCycle( const int cycle )
       {
           M_cycle = cycle;
       }
 
-    const
-    long & cycle() const
+    int cycle() const
       {
           return M_cycle;
       }
@@ -272,21 +303,51 @@ public:
           return M_line_cont;
       }
     const
+    ArcCont & arcCont() const
+      {
+          return M_arc_cont;
+      }
+    const
     CircleCont & circleCont() const
       {
           return M_circle_cont;
       }
     const
+    CircleCont & filledCircleCont() const
+      {
+          return M_filled_circle_cont;
+      }
+    const
     TriangleCont & triangleCont() const
       {
           return M_triangle_cont;
       }
     const
+    TriangleCont & filledTriangleCont() const
+      {
+          return M_filled_triangle_cont;
+      }
+    const
     RectCont & rectCont() const
       {
           return M_rect_cont;
       }
     const
+    RectCont & filledRectCont() const
+      {
+          return M_filled_rect_cont;
+      }
+    const
+    SectorCont & sectorCont() const
+      {
+          return M_sector_cont;
+      }
+    const
+    SectorCont & filledSectorCont() const
+      {
+          return M_filled_sector_cont;
+      }
+    const
     MessageCont & messageCont() const
       {
           return M_message_cont;
@@ -300,12 +361,20 @@ private:
                    const char * buf );
     bool addLine( const boost::int32_t level,
                   const char * buf );
+    bool addArc( const boost::int32_t level,
+                 const char * buf );
     bool addCircle( const boost::int32_t level,
-                    const char * buf );
+                    const char * buf,
+                    const bool fill );
     bool addTriangle( const boost::int32_t level,
-                      const char * buf );
+                      const char * buf,
+                      const bool fill );
     bool addRect( const boost::int32_t level,
-                  const char * buf );
+                  const char * buf,
+                  const bool fill );
+    bool addSector( const boost::int32_t level,
+                    const char * buf,
+                    const bool fill );
     bool addMessage( const boost::int32_t level,
                      const char * buf );
 };
