@@ -65,9 +65,9 @@ DebugLogHolder::~DebugLogHolder()
 void
 DebugLogHolder::clear()
 {
-    for ( int i = 1; i <= 11; ++i )
+    for ( int i = 1; i <= 12; ++i )
     {
-        M_player_data[i-1].clear();
+        M_data_entity[i-1].clear();
     }
 }
 
@@ -88,7 +88,7 @@ DebugLogHolder::setDir( const std::string & team_name,
         return false;
     }
 
-    if ( unum < 1 || 11 < unum )
+    if ( unum < 1 || 12 < unum )
     {
         std::cerr << "***ERROR*** DebugLogHolder::setDir()"
                   << " Invalid unum! " << unum
@@ -106,35 +106,41 @@ DebugLogHolder::setDir( const std::string & team_name,
 
     //for ( int i = 1; i <= 11; ++i )
     {
-        int idx = unum - 1;
-        M_player_data[idx].clear();
+        DataEntity & de = M_data_entity[unum - 1];
+        de.clear();
 
-        M_player_data[idx].side_ = side;
-
-        std::ostringstream ostr;
-        ostr << team_name
-             << '-'
-             << unum
-             << DEFAULT_EXTENSION;
-        ostr << std::flush;
+        de.side_ = side;
 
         // open file stream
-        std::string filepath = base_path + ostr.str();
-        std::cerr << "open debug file [" << filepath << "]" << std::endl;
-        M_player_data[idx].fin_.open( filepath.c_str() );
+        std::string filepath = base_path;
+        {
+            std::ostringstream ostr;
+            if ( unum == 12 )
+            {
+                ostr << team_name << "-coach.log";
+            }
+            else
+            {
+                ostr << team_name << '-' << unum << ".log";
+            }
 
-        if ( ! M_player_data[idx].fin_.is_open()
-             || ! M_player_data[idx].fin_.good() )
+            filepath += ostr.str();
+        }
+
+        std::cerr << "open debug file [" << filepath << "]" << std::endl;
+        de.fin_.open( filepath.c_str() );
+
+        if ( ! de.fin_.is_open()
+             || ! de.fin_.good() )
         {
             std::cerr << "***ERROR*** DebugLogHolder::setDir()"
                       << " Failed to open [" << filepath << "]"
                       << std::endl;
-            M_player_data[idx].clear();
+            de.clear();
             return false;
         }
 
-        // if file open is succeeded,
-        // try to record cycle changed stream positions
+        // record stream positions where cycle number is changed.
 
         std::streampos pos = 0;
         std::string buf;
@@ -142,7 +148,7 @@ DebugLogHolder::setDir( const std::string & team_name,
         int cycle;
 
         int n_line = 0;
-        std::ifstream & fin = M_player_data[idx].fin_;
+        std::ifstream & fin = de.fin_;
         while ( std::getline( fin, buf ) )
         {
             ++n_line;
@@ -151,7 +157,7 @@ DebugLogHolder::setDir( const std::string & team_name,
             {
                 if ( cycle > prev_cycle )
                 {
-                    M_player_data[idx].cycle_map_.insert( std::make_pair( cycle, pos ) );
+                    de.cycle_map_.insert( std::make_pair( cycle, pos ) );
                     prev_cycle = cycle;
                 }
 
@@ -167,11 +173,11 @@ DebugLogHolder::setDir( const std::string & team_name,
         }
 
         // reset get pointer
-        M_player_data[idx].fin_.clear();
-        M_player_data[idx].fin_.seekg( 0 );
+        de.fin_.clear();
+        de.fin_.seekg( 0 );
 
         std::cerr << unum << " : read " << n_line << " lines"
-                  << " cycle size = " << M_player_data[idx].cycle_map_.size()
+                  << " cycle size = " << de.cycle_map_.size()
                   << std::endl;
     }
 
@@ -187,18 +193,17 @@ DebugLogHolder::getCycleData( const int unum,
                               const int cycle,
                               boost::shared_ptr< DebugLogData > data_ptr )
 {
-    if ( unum < 1 || 11 < unum )
+    if ( unum < 1 || 12 < unum )
     {
         return false;
     }
 
-    const int idx = unum - 1;
+    DataEntity & de = M_data_entity[unum - 1];
 
     // get the start stream position of 'cycle'
-    std::map< int, std::streampos >::iterator it
-        = M_player_data[idx].cycle_map_.find( cycle );
+    std::map< int, std::streampos >::iterator it = de.cycle_map_.find( cycle );
 
-    if ( it == M_player_data[idx].cycle_map_.end() )
+    if ( it == de.cycle_map_.end() )
     {
         // no data!
         return false;
@@ -208,7 +213,7 @@ DebugLogHolder::getCycleData( const int unum,
     // seek & analyze data
 
     // seek stream position
-    std::ifstream & fin = M_player_data[idx].fin_;
+    std::ifstream & fin = de.fin_;
     fin.clear();
     fin.seekg( it->second );
 
@@ -244,7 +249,7 @@ DebugLogHolder::getCycleData( const int unum,
         if ( ! data_ptr->parse( buf + n_read ) )
         {
             std::cerr << "***ERROR*** DebugLogHolder::getCycleData()"
-                      << " Parse Error! unum = " << idx + 1
+                      << " Parse Error! unum = " << unum
                       << "  cycle = " << cycle
                       << "  line = " << n_line
                       << std::endl;
@@ -262,7 +267,7 @@ bool
 DebugLogHolder::seekData( const int unum,
                           const int cycle )
 {
-    if ( unum < 1 || 11 < unum )
+    if ( unum < 1 || 12 < unum )
     {
         std::cerr << "DebugLogHolder::seekData. Invalid number"
                   << std::endl;
@@ -277,9 +282,9 @@ DebugLogHolder::seekData( const int unum,
     }
     */
 
-    const int idx = unum - 1;
+    DataEntity & de = M_data_entity[unum - 1];
 
-    if ( ! M_player_data[idx].fin_.is_open() )
+    if ( ! de.fin_.is_open() )
     {
         return false;
     }
@@ -292,9 +297,8 @@ DebugLogHolder::seekData( const int unum,
     int first_cycle = std::max( 1, cycle - MAX_SPAN + 1 );
     for ( ; first_cycle <= cycle; ++first_cycle )
     {
-        std::map< int, std::streampos >::iterator it
-            = M_player_data[idx].cycle_map_.find( first_cycle );
-        if ( it != M_player_data[idx].cycle_map_.end() )
+        std::map< int, std::streampos >::iterator it = de.cycle_map_.find( first_cycle );
+        if ( it != de.cycle_map_.end() )
         {
             found = true;
             first_pos = it->second;
@@ -316,15 +320,15 @@ DebugLogHolder::seekData( const int unum,
     // seek & analyze data
 
     // reset old data
-    M_player_data[idx].data_list_.clear();
+    de.data_list_.clear();
 
     const int last_cycle = cycle + MAX_SPAN;
-    for ( int cyc = first_cycle; cyc < last_cycle; ++cyc )
+    for ( int c = first_cycle; c < last_cycle; ++c )
     {
-        boost::shared_ptr< DebugLogData > data( new DebugLogData( cyc ) );
-        if ( getCycleData( unum, cyc, data ) )
+        boost::shared_ptr< DebugLogData > data( new DebugLogData( c ) );
+        if ( getCycleData( unum, c, data ) )
         {
-            M_player_data[idx].data_list_.push_back( data );
+            de.data_list_.push_back( data );
         }
     }
 
@@ -339,7 +343,7 @@ DebugLogHolder::seekData( const int unum,
 bool
 DebugLogHolder::incDataCycle( const int unum )
 {
-    if ( unum < 1 || 11 < unum )
+    if ( unum < 1 || 12 < unum )
     {
         std::cerr << "***ERROR*** DebugLogHolder::incDataCycle()"
                   << " Invalid unum " << unum
@@ -347,9 +351,9 @@ DebugLogHolder::incDataCycle( const int unum )
         return false;
     }
 
-    const int idx = unum - 1;
+    DataEntity & de = M_data_entity[unum - 1];
 
-    if ( ! M_player_data[idx].fin_.is_open() )
+    if ( ! de.fin_.is_open() )
     {
         //std::cerr << "***ERROR*** DebugLogHolder::incDataCycle()"
         //          << " File is not opened for unum = " << unum
@@ -357,7 +361,7 @@ DebugLogHolder::incDataCycle( const int unum )
         return false;
     }
 
-    if ( M_player_data[idx].data_list_.empty() )
+    if ( de.data_list_.empty() )
     {
         std::cerr << "***ERROR*** DebugLogHolder::incDataCycle()"
                   << " No current data! unum = " << unum
@@ -365,52 +369,25 @@ DebugLogHolder::incDataCycle( const int unum )
         return false;
     }
 
-    bool next_found = false;
-    const DataList::iterator end = M_player_data[idx].data_list_.end();
-    for ( DataList::iterator it = M_player_data[idx].data_list_.begin();
+    for ( DataList::iterator it = de.data_list_.begin(),
+              end = de.data_list_.end();
           it != end;
           ++it )
     {
         if ( (*it)->cycle() == M_cycle )
         {
-            // cycle info in data equals to current focused cycle
+            // The data cycle equals to the current focused cycle
             ++it;
             if ( it != end )
             {
                 M_cycle = (*it)->cycle();
-                next_found = true;
+                return true;
             }
             break;
         }
     }
 
-    if ( ! next_found )
-    {
-        std::cerr << "***ERROR*** DebugLogHolder::incDataCycle()"
-                  << " Not found next data" << std::endl;
-        return false;
-    }
-
-    int new_cycle = M_player_data[idx].data_list_.back()->cycle() + 1;
-    boost::shared_ptr< DebugLogData > next_data_ptr( new DebugLogData( new_cycle ) );
-
-    // max trial is 10 cycles
-    // if next possible cycle found, return immediately
-    for ( int i = 0; i < 10; ++i )
-    {
-        if ( getCycleData( unum, new_cycle, next_data_ptr ) )
-        {
-            M_player_data[idx].data_list_.pop_front();
-            M_player_data[idx].data_list_.push_back( next_data_ptr );
-            return true;
-        }
-        ++new_cycle;
-        next_data_ptr->setCycle( new_cycle );
-    }
-
-    std::cerr << "***ERROR*** DebugLogHolder::incDataCycle()"
-              << " Not found data" << std::endl;
-    return false;
+    return seekData( unum, M_cycle + 1 );
 }
 
 /*-------------------------------------------------------------------*/
@@ -420,7 +397,7 @@ DebugLogHolder::incDataCycle( const int unum )
 bool
 DebugLogHolder::decDataCycle( const int unum )
 {
-    if ( unum < 1 || 11 < unum )
+    if ( unum < 1 || 12 < unum )
     {
         std::cerr << "***ERROR*** DebugLogHolder::incDataCycle()"
                   << " Invalid unum " << unum
@@ -428,9 +405,9 @@ DebugLogHolder::decDataCycle( const int unum )
         return false;
     }
 
-    const int idx = unum - 1;
+    DataEntity & de = M_data_entity[unum - 1];
 
-    if ( ! M_player_data[idx].fin_.is_open() )
+    if ( ! de.fin_.is_open() )
     {
         //std::cerr << "***ERROR*** DebugLogHolder::decDataCycle()"
         //          << " File is not opened for unum = " << unum
@@ -438,7 +415,7 @@ DebugLogHolder::decDataCycle( const int unum )
         return false;
     }
 
-    if ( M_player_data[idx].data_list_.empty() )
+    if ( de.data_list_.empty() )
     {
         std::cerr << "***ERROR*** DebugLogHolder::decDataCycle()"
                   << " No current data! unum = " << unum
@@ -446,9 +423,8 @@ DebugLogHolder::decDataCycle( const int unum )
         return false;
     }
 
-    bool next_found = false;
-    const DataList::reverse_iterator rend = M_player_data[idx].data_list_.rend();
-    for ( DataList::reverse_iterator it = M_player_data[idx].data_list_.rbegin();
+    for ( DataList::reverse_iterator it = de.data_list_.rbegin(),
+              rend = de.data_list_.rend();
           it != rend;
           ++it )
     {
@@ -458,38 +434,11 @@ DebugLogHolder::decDataCycle( const int unum )
             if ( it != rend )
             {
                 M_cycle = (*it)->cycle();
-                next_found = true;
+                return true;
             }
             break;
         }
     }
 
-    if ( ! next_found )
-    {
-        return false;
-    }
-
-    int new_cycle = M_player_data[idx].data_list_.front()->cycle() - 1;
-    if ( new_cycle <= 0 )
-    {
-        return false;
-    }
-
-    boost::shared_ptr< DebugLogData > next_data_ptr( new DebugLogData( new_cycle ) );
-    for ( int i = 0; i < 10; ++i )
-    {
-        if ( getCycleData( unum, new_cycle, next_data_ptr ) )
-        {
-            M_player_data[idx].data_list_.pop_back();
-            M_player_data[idx].data_list_.push_front( next_data_ptr );
-            return true;
-        }
-        --new_cycle;
-        if ( new_cycle <= 0 )
-        {
-            return false;
-        }
-    }
-
-    return false;
+    return seekData( unum, M_cycle - 1 );
 }
