@@ -12,7 +12,7 @@
 
  This code is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
- the Free Software Foundation; either version 2, or (at your option)
+ the Free Software Foundation; either version 3, or (at your option)
  any later version.
 
  This code is distributed in the hope that it will be useful,
@@ -77,7 +77,7 @@ MonitorViewData::MonitorViewData( const rcsc::rcg::short_showinfo_t2 & show,
                                   const rcsc::rcg::TeamT & team_r )
     : M_playmode( pmode )
     , M_ball( show.ball )
-    , M_cycle( static_cast< long >( ntohs( show.time ) ) )
+    , M_cycle( static_cast< int >( ntohs( show.time ) ) )
 {
     if ( M_cycle == 65535 ) M_cycle = 0;
 
@@ -106,7 +106,7 @@ MonitorViewData::MonitorViewData( const rcsc::rcg::short_showinfo_t2 & show,
 MonitorViewData::MonitorViewData( const rcsc::rcg::showinfo_t2 & show )
     : M_playmode( show.pmode )
     , M_ball( show.ball )
-    , M_cycle( static_cast< long >( ntohs( show.time ) ) )
+    , M_cycle( static_cast< int >( ntohs( show.time ) ) )
 {
     if ( M_cycle == 65535 ) M_cycle = 0;
 
@@ -137,7 +137,7 @@ MonitorViewData::MonitorViewData( const rcsc::rcg::showinfo_t2 & show )
 MonitorViewData::MonitorViewData( const rcsc::rcg::showinfo_t & show )
     : M_playmode( show.pmode )
     , M_ball( show.pos[0] )
-    , M_cycle( static_cast< long >( ntohs( show.time ) ) )
+    , M_cycle( static_cast< int >( ntohs( show.time ) ) )
 {
     if ( M_cycle == 65535 ) M_cycle = 0;
 
