@@ -12,7 +12,7 @@
 
  This code is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
- the Free Software Foundation; either version 2, or (at your option)
+ the Free Software Foundation; either version 3, or (at your option)
  any later version.
 
  This code is distributed in the hope that it will be useful,
@@ -49,7 +49,7 @@ private:
     Team M_teams[2];
     Ball M_ball;
     std::vector< Player > M_players;
-    long M_cycle; //!< current game cycle
+    int M_cycle; //!< current game cycle
 
     //! not used
     MonitorViewData();
@@ -140,10 +140,9 @@ public:
 
     /*!
       \brief returns game cycle info
-      \return const reference to the cycle data
+      \return cycle value
     */
-    const
-    long & cycle() const
+    int cycle() const
       {
           return M_cycle;
       }
