@@ -38,8 +38,19 @@ struct Point {
 
     Point( const int xx,
            const int yy )
-        : x( xx )
-        , y( yy )
+        : x( xx ),
+          y( yy )
+      { }
+};
+
+struct PointF {
+    double x;
+    double y;
+
+    PointF( const double & xx,
+            const double & yy )
+        : x( xx ),
+          y( yy )
       { }
 };
 
