@@ -87,8 +87,8 @@ draw_communication( QPainter & painter,
         const boost::shared_ptr< DebugViewData::SelfT > self = v->self();
         if ( ! self ) continue;
 
-        const double ix = opt.screenXF( (double)self->x_ / rcsc::rcg::SHOWINFO_SCALE2 * reverse );
-        const double iy = opt.screenYF( (double)self->y_ / rcsc::rcg::SHOWINFO_SCALE2 * reverse );
+        const double ix = opt.screenXF( self->x() * reverse );
+        const double iy = opt.screenYF( self->y() * reverse );
 
         painter.drawEllipse( QRectF( ix - say_r, iy - say_r, say_r * 2, say_r * 2 ) );
     }
@@ -104,8 +104,8 @@ draw_communication( QPainter & painter,
             return;
         }
 
-        const QPointF self_pos( opt.screenXF( self->x_ / rcsc::rcg::SHOWINFO_SCALE2 * reverse ),
-                                opt.screenYF( self->y_ / rcsc::rcg::SHOWINFO_SCALE2 * reverse ) );
+        const QPointF self_pos( opt.screenXF( self->x() * reverse ),
+                                opt.screenYF( self->y() * reverse ) );
 
         const std::vector< Player > & players = monitor_view.players();
         const std::vector< Player >::const_iterator p_end = players.end();
@@ -208,65 +208,71 @@ DebugPainter::draw( QPainter & painter )
 
     const DrawConfig & dconf = DrawConfig::instance();
 
-    // draw self
-    if ( opt.showDebugViewSelf() )
+    if ( number != 12 )
     {
-        drawSelf( painter, self_side, *view );
+        // draw self
+        if ( opt.showDebugViewSelf() )
+        {
+            drawSelf( painter, self_side, *view );
+        }
+
+        // draw players
+        if ( opt.showDebugViewTeammates() )
+        {
+            drawPlayers( painter,
+                         self_side,
+                         // *view,
+                         view->teammates(),
+                         // ( opt.showDebugViewTarget()
+                         //   ? view->targetTeammate()
+                         //   : -1 ),
+                         dconf.debugTeammateBrush() );
+            drawPlayers( painter,
+                         self_side,
+                         // *view,
+                         view->unknownTeammates(),
+                         // -1,
+                         dconf.debugUnknownTeammateBrush() );
+
+            draw_communication( painter,
+                                self_side,
+                                *monitor_view,
+                                it->second,
+                                *view );
+        }
+
+        if ( opt.showDebugViewOpponents() )
+        {
+            drawPlayers( painter,
+                         self_side,
+                         // *view,
+                         view->opponents(),
+                         // -1,
+                         dconf.debugOpponentBrush() );
+            drawPlayers( painter,
+                         self_side,
+                         // *view,
+                         view->unknownOpponents(),
+                         // -1,
+                         dconf.debugUnknownOpponentBrush() );
+            drawPlayers( painter,
+                         self_side,
+                         // *view,
+                         view->unknownPlayers(),
+                         // -1,
+                         dconf.debugUnknownPlayerBrush() );
+        }
+
+        // draw ball
+        if ( opt.showDebugViewBall()
+             && view->ball() )
+        {
+            drawBall( painter, self_side, *view );
+        }
     }
 
-    // draw players
-    if ( opt.showDebugViewTeammates() )
-    {
-        drawPlayers( painter,
-                     self_side,
-                     *view,
-                     view->teammates(),
-                     ( opt.showDebugViewTarget()
-                       ? view->targetTeammate()
-                       : -1 ),
-                     dconf.debugTeammateBrush() );
-        drawPlayers( painter,
-                     self_side,
-                     *view,
-                     view->unknownTeammates(),
-                     -1,
-                     dconf.debugUnknownTeammateBrush() );
-
-        draw_communication( painter,
-                            self_side,
-                            *monitor_view,
-                            it->second,
-                            *view );
-    }
-
-    if ( opt.showDebugViewOpponents() )
-    {
-        drawPlayers( painter,
-                     self_side,
-                     *view,
-                     view->opponents(),
-                     -1,
-                     dconf.debugOpponentBrush() );
-        drawPlayers( painter,
-                     self_side,
-                     *view,
-                     view->unknownOpponents(),
-                     -1,
-                     dconf.debugUnknownOpponentBrush() );
-        drawPlayers( painter,
-                     self_side,
-                     *view,
-                     view->unknownPlayers(),
-                     -1,
-                     dconf.debugUnknownPlayerBrush() );
-    }
-
-    // draw ball
-    if ( opt.showDebugViewBall()
-         && view->ball() )
-    {
-        drawBall( painter, self_side, *view );
-    }
+    // draw targets
+    drawTarget( painter, self_side, *view );
 
     // draw shapes
     if ( opt.showDebugViewShape() )
@@ -327,31 +333,31 @@ DebugPainter::drawSelf( QPainter & painter,
     const double reverse = ( self_side == rcsc::RIGHT
                              ? -1.0
                              : 1.0 );
-    const double ix = opt.screenXF( (double)self->x_ / rcsc::rcg::SHOWINFO_SCALE2 * reverse );
-    const double iy = opt.screenYF( (double)self->y_ / rcsc::rcg::SHOWINFO_SCALE2 * reverse );
+    const double ix = opt.screenXF( self->x() * reverse );
+    const double iy = opt.screenYF( self->y() * reverse );
     const double r = std::max( 2.0,
                                ( opt.enlargeMode()
                                  ? opt.scaleF( 1.0 )
                                  : opt.scaleF( 0.3 ) ) );
 
-    // draw targets
-    if ( opt.showDebugViewTarget()
-         &&  view.targetPoint() )
-    {
-        double tx = opt.screenXF( view.targetPoint()->x * reverse );
-        double ty = opt.screenYF( view.targetPoint()->y * reverse );
+    // // draw target
+    // if ( opt.showDebugViewTarget()
+    //      && view.targetPoint() )
+    // {
+    //     double tx = opt.screenXF( view.targetPoint()->x * reverse );
+    //     double ty = opt.screenYF( view.targetPoint()->y * reverse );
 
-        painter.setPen( dconf.debugTargetPen() );
-        painter.setBrush( dconf.transparentBrush() );
+    //     painter.setPen( dconf.debugTargetPen() );
+    //     painter.setBrush( dconf.transparentBrush() );
 
-        painter.drawLine( QLineF( tx - r, ty - r,
-                                  tx + r, ty + r ) );
-        painter.drawLine( QLineF( tx - r, ty + r,
-                                  tx + r, ty - r ) );
-    }
+    //     painter.drawLine( QLineF( tx - r, ty - r,
+    //                               tx + r, ty + r ) );
+    //     painter.drawLine( QLineF( tx - r, ty + r,
+    //                               tx + r, ty - r ) );
+    // }
 
     // draw body half circle
-    double body_start_dir = - ( (double)self->body_ + 90.0 );
+    double body_start_dir = - ( self->body() + 90.0 );
     if ( opt.reverseSide() ) body_start_dir += 180.0;
     if ( self_side == rcsc::RIGHT ) body_start_dir -= 180.0;
 
@@ -377,7 +383,7 @@ DebugPainter::drawSelf( QPainter & painter,
 
     // draw face angle
     {
-        rcsc::AngleDeg face_angle = (double)self->body_ + (double)self->neck_;
+        rcsc::AngleDeg face_angle = self->body() + self->neck();
         if ( opt.reverseSide() ) face_angle += 180.0;
 
         double face_r = 3.0;
@@ -426,10 +432,10 @@ DebugPainter::drawBall( QPainter & painter,
                              ? -1.0
                              : 1.0 );
 
-    rcsc::Vector2D bpos( (double)ball->x_ / rcsc::rcg::SHOWINFO_SCALE2 * reverse,
-                         (double)ball->y_ / rcsc::rcg::SHOWINFO_SCALE2 * reverse );
-    rcsc::Vector2D bvel( (double)ball->vx_ / rcsc::rcg::SHOWINFO_SCALE2 * reverse,
-                         (double)ball->vy_ / rcsc::rcg::SHOWINFO_SCALE2 * reverse );
+    rcsc::Vector2D bpos( ball->x() * reverse,
+                         ball->y() * reverse );
+    rcsc::Vector2D bvel( ball->vx() * reverse,
+                         ball->vy() * reverse );
 
     const double ball_decay = rcsc::ServerParam::i().ballDecay();
     const QPointF p( opt.screenXF( bpos.x ),
@@ -537,9 +543,9 @@ DebugPainter::drawBall( QPainter & painter,
 void
 DebugPainter::drawPlayers( QPainter & painter,
                            const rcsc::SideID self_side,
-                           const DebugViewData & view,
+                           // const DebugViewData & view,
                            const DebugViewData::PlayerCont & players,
-                           const int target_number,
+                           // const int target_number,
                            const QBrush & body_brush ) const
 {
     const Options & opt = Options::instance();
@@ -559,12 +565,12 @@ DebugPainter::drawPlayers( QPainter & painter,
           it != end;
           ++it )
     {
-        const QPointF p( opt.screenXF( (double)(*it)->x_ / rcsc::rcg::SHOWINFO_SCALE2 * reverse ),
-                         opt.screenYF( (double)(*it)->y_ / rcsc::rcg::SHOWINFO_SCALE2 * reverse ) );
+        const QPointF p( opt.screenXF( (*it)->x() * reverse ),
+                         opt.screenYF( (*it)->y() * reverse ) );
 
-        if ( (*it)->body_ != -360 )
+        if ( (*it)->hasBody() )
         {
-            double body_start_dir = - ( (double)(*it)->body_ + 90.0 );
+            double body_start_dir = - ( (*it)->body() + 90.0 );
             if ( opt.reverseSide() ) body_start_dir += 180.0;
             if ( self_side == rcsc::RIGHT ) body_start_dir -= 180.0;
             //double body_end_dir = body_start_dir + 180.0;
@@ -597,23 +603,23 @@ DebugPainter::drawPlayers( QPainter & painter,
                               QString::number( (*it)->unum_ ) );
         }
 
-        if ( target_number == (*it)->unum_ )
-        {
-            painter.setPen( dconf.debugTargetPen() );
-            painter.setBrush( dconf.transparentBrush() );
+        // if ( target_number == (*it)->unum_ )
+        // {
+        //     painter.setPen( dconf.debugTargetPen() );
+        //     painter.setBrush( dconf.transparentBrush() );
 
-            const boost::shared_ptr< DebugViewData::SelfT > self = view.self();
-            if ( self )
-            {
-                QPointF s( opt.screenXF( (double)self->x_ / rcsc::rcg::SHOWINFO_SCALE2 * reverse ),
-                           opt.screenYF( (double)self->y_ / rcsc::rcg::SHOWINFO_SCALE2 * reverse ) );
-                painter.drawLine( QLineF( s, p ) );
-            }
+        //     const boost::shared_ptr< DebugViewData::SelfT > self = view.self();
+        //     if ( self )
+        //     {
+        //         QPointF s( opt.screenXF( (double)self->x_ / rcsc::rcg::SHOWINFO_SCALE2 * reverse ),
+        //                    opt.screenYF( (double)self->y_ / rcsc::rcg::SHOWINFO_SCALE2 * reverse ) );
+        //         painter.drawLine( QLineF( s, p ) );
+        //     }
 
-            double rr = r + 2;
-            painter.drawEllipse( QRectF( p.x() - rr, p.y() - rr,
-                                         rr * 2, rr * 2 ) );
-        }
+        //     double rr = r + 2;
+        //     painter.drawEllipse( QRectF( p.x() - rr, p.y() - rr,
+        //                                  rr * 2, rr * 2 ) );
+        // }
 
         if ( comment
              && ! (*it)->comment_.empty() )
@@ -631,6 +637,90 @@ DebugPainter::drawPlayers( QPainter & painter,
 /*-------------------------------------------------------------------*/
 /*!
 
+*/
+void
+DebugPainter::drawTarget( QPainter & painter,
+                          const rcsc::SideID self_side,
+                          const DebugViewData & view ) const
+{
+    const Options & opt = Options::instance();
+
+    if ( ! opt.showDebugViewTarget() )
+    {
+        return;
+    }
+
+    const DrawConfig & dconf = DrawConfig::instance();
+    const double reverse = ( self_side == rcsc::RIGHT
+                             ? -1.0
+                             : 1.0 );
+
+    const double r = std::max( 2.0,
+                               ( opt.enlargeMode()
+                                 ? opt.scaleF( 0.25 )
+                                 : opt.scaleF( 0.07 ) ) );
+
+    //
+    // target point
+    //
+    if ( view.targetPoint() )
+    {
+        double tx = opt.screenXF( view.targetPoint()->x * reverse );
+        double ty = opt.screenYF( view.targetPoint()->y * reverse );
+
+        painter.setPen( dconf.debugTargetPen() );
+        painter.setBrush( dconf.transparentBrush() );
+
+        painter.drawLine( QLineF( tx - r, ty - r,
+                                  tx + r, ty + r ) );
+        painter.drawLine( QLineF( tx - r, ty + r,
+                                  tx + r, ty - r ) );
+    }
+
+    //
+    // target teammate
+    //
+    const int target_unum = view.targetTeammate();
+    if ( 1 <= target_unum
+         && target_unum <= 11 )
+    {
+        const DebugViewData::PlayerCont::const_iterator end = view.teammates().end();
+        for ( DebugViewData::PlayerCont::const_iterator it = view.teammates().begin();
+              it != end;
+              ++it )
+        {
+            if ( target_unum == (*it)->unum_ )
+            {
+                const QPointF p( opt.screenXF( (double)(*it)->x_ / rcsc::rcg::SHOWINFO_SCALE2 * reverse ),
+                                 opt.screenYF( (double)(*it)->y_ / rcsc::rcg::SHOWINFO_SCALE2 * reverse ) );
+
+                painter.setPen( dconf.debugTargetPen() );
+                painter.setBrush( dconf.transparentBrush() );
+
+                const boost::shared_ptr< DebugViewData::SelfT > self = view.self();
+                if ( self
+                     && self->unum_ != 12 )
+                {
+                    QPointF s( opt.screenXF( (double)self->x_ / rcsc::rcg::SHOWINFO_SCALE2 * reverse ),
+                               opt.screenYF( (double)self->y_ / rcsc::rcg::SHOWINFO_SCALE2 * reverse ) );
+                    painter.drawLine( QLineF( s, p ) );
+                }
+
+                double rr = r + 2;
+                painter.drawEllipse( QRectF( p.x() - rr, p.y() - rr,
+                                             rr * 2, rr * 2 ) );
+
+                break;
+            }
+        }
+
+
+    }
+}
+
+/*-------------------------------------------------------------------*/
+/*!
+
 */
 void
 DebugPainter::drawLines( QPainter & painter,
