@@ -40,6 +40,7 @@
 #include "options.h"
 #include "main_data.h"
 
+#include <rcsc/common/server_param.h>
 #include <rcsc/geom/vector_2d.h>
 
 #include <iostream>
@@ -178,9 +179,9 @@ DetailDialog::createPlayerLabels()
     layout->addWidget( M_player_polar_vel, row, 2, Qt::AlignRight );
     ++row;
 
-    layout->addWidget( new QLabel( tr( "MaxTurn " ), group_box ),
+    layout->addWidget( new QLabel( tr( "MaxTurn " ) ),
                        row, 0, Qt::AlignRight );
-    M_max_turn_moment = new QLabel( tr( "   0.00" ), group_box );
+    M_max_turn_moment = new QLabel( tr( "   0.00" ) );
     layout->addWidget( M_max_turn_moment, row, 1, Qt::AlignRight );
     ++row;
 
@@ -201,15 +202,33 @@ DetailDialog::createPlayerLabels()
     layout->addWidget( M_player_head, row, 1, Qt::AlignRight );
     ++row;
 
-    layout->addWidget( new QLabel( tr( "PointToPos " ), group_box ),
+//     layout->addWidget( new QLabel( tr( "CatchProb " ) ),
+//                        row, 0, Qt::AlignRight );
+//     M_player_catch_prob = new QLabel( tr( "   0.0" ) );
+//     layout->addWidget( M_player_catch_prob, row, 1, Qt::AlignRight );
+//     ++row;
+
+    layout->addWidget( new QLabel( tr( "TackleProb " ) ),
                        row, 0, Qt::AlignRight );
-    M_player_pointto_pos = new QLabel( tr( "      -,      -" ), group_box );
+    M_player_tackle_prob = new QLabel( tr( "   0.0" ) );
+    layout->addWidget( M_player_tackle_prob, row, 1, Qt::AlignRight );
+    ++row;
+
+    layout->addWidget( new QLabel( tr( "FoulProb " ) ),
+                       row, 0, Qt::AlignRight );
+    M_player_foul_prob = new QLabel( tr( "   0.0" ) );
+    layout->addWidget( M_player_foul_prob, row, 1, Qt::AlignRight );
+    ++row;
+
+    layout->addWidget( new QLabel( tr( "PointToPos " ) ),
+                       row, 0, Qt::AlignRight );
+    M_player_pointto_pos = new QLabel( tr( "      -,      -" ) );
     layout->addWidget( M_player_pointto_pos, row, 1, Qt::AlignRight );
     ++row;
 
-    layout->addWidget( new QLabel( tr( "Focus " ), group_box ),
+    layout->addWidget( new QLabel( tr( "Focus " ) ),
                        row, 0, Qt::AlignRight );
-    M_player_focus_target = new QLabel( tr( "      -,      -" ), group_box );
+    M_player_focus_target = new QLabel( tr( "      -,      -" ) );
     layout->addWidget( M_player_focus_target, row, 1, Qt::AlignRight );
     ++row;
 
@@ -272,21 +291,21 @@ DetailDialog::createPlayerLabels()
     layout->addWidget( M_change_view_count, row, 1, Qt::AlignRight );
     ++row;
 
-    layout->addWidget( new QLabel( tr( "Tackle " ), group_box ),
+    layout->addWidget( new QLabel( tr( "Tackle " ) ),
                        row, 0, Qt::AlignRight );
-    M_tackle_count = new QLabel( tr( "     0" ), group_box );
+    M_tackle_count = new QLabel( tr( "     0" ) );
     layout->addWidget( M_tackle_count, row, 1, Qt::AlignRight );
     ++row;
 
-    layout->addWidget( new QLabel( tr( "PointTo " ), group_box ),
+    layout->addWidget( new QLabel( tr( "PointTo " ) ),
                        row, 0, Qt::AlignRight );
-    M_pointto_count = new QLabel( tr( "     0" ), group_box );
+    M_pointto_count = new QLabel( tr( "     0" ) );
     layout->addWidget( M_pointto_count, row, 1, Qt::AlignRight );
     ++row;
 
-    layout->addWidget( new QLabel( tr( "AttentionTo " ), group_box ),
+    layout->addWidget( new QLabel( tr( "AttentionTo " ) ),
                        row, 0, Qt::AlignRight );
-    M_attentionto_count = new QLabel( tr( "     0" ), group_box );
+    M_attentionto_count = new QLabel( tr( "     0" ) );
     layout->addWidget( M_attentionto_count, row, 1, Qt::AlignRight );
     ++row;
 
@@ -421,6 +440,7 @@ DetailDialog::updateLabels()
     }
 
     const int player_index = std::abs( number ) - 1 + ( number > 0 ? 0 : 11 );
+    const rcsc::ServerParam & SP = rcsc::ServerParam::i();
     const Player & player = view->players()[player_index];
     const rcsc::PlayerType & player_type
         = M_main_data.viewHolder().playerType( player.type() );
@@ -510,6 +530,84 @@ DetailDialog::updateLabels()
         M_player_head->setText( QString::fromAscii( buf ) );
     }
 
+    {
+        rcsc::Vector2D player_to_ball( ball.x() - player.x(),
+                                       ball.y() - player.y() );
+        player_to_ball.rotate( - player.body() );
+#if 0
+        //
+        // catch prob
+        //
+        if ( player.isGoalie() )
+        {
+            const double catchable_area
+                = std::sqrt( std::pow( SP.catchAreaWidth() * 0.5, 2 )
+                             + std::pow( SP.catchAreaLength(), 2 ) );
+            const double stretch_l = SP.catchAreaLength() * player_type.catchAreaLengthStretch();
+            const double stretch_area = std::sqrt( std::pow( SP.catchAreaWidth() * 0.5, 2 )
+                                                   + std::pow( stretch_l, 2 ) );
+            const double ball_dist = player_to_ball.r();
+
+            double catch_prob = SP.catchProbability();
+            if ( ball_dist > stretch_area )
+            {
+                catch_prob = 0.0;
+            }
+            else if ( ball_dist > catchable_area )
+            {
+                double x = ball_dist * ( stretch_l / stretch_area );
+                catch_prob
+                    = SP.catchProbability()
+                    - SP.catchProbability() * ( ( x - SP.catchAreaLength() )
+                                                / ( stretch_l - SP.catchAreaLength() ) );
+            }
+
+            snprintf( buf, 64, " %.4f", catch_prob );
+            M_player_catch_prob->setText( QString::fromAscii( buf ) );
+        }
+        else
+        {
+            M_player_catch_prob->setText( tr( "0.0000" ) );
+        }
+#endif
+        //
+        // tackle prob
+        //
+        double tackle_dist = ( player_to_ball.x > 0.0
+                               ? SP.tackleDist()
+                               : SP.tackleBackDist() );
+        double tackle_fail_prob = 1.0;
+        if ( tackle_dist > 1.0e-5 )
+        {
+            tackle_fail_prob = ( std::pow( std::fabs( player_to_ball.x ) / tackle_dist,
+                                           SP.tackleExponent() )
+                                 + std::pow( player_to_ball.absY() / SP.tackleWidth(),
+                                             SP.tackleExponent() ) );
+            tackle_fail_prob = std::min( 1.0, tackle_fail_prob );
+            tackle_fail_prob = std::max( 0.0, tackle_fail_prob );
+        }
+
+        snprintf( buf, 64, " %.4f", 1.0 - tackle_fail_prob );
+        M_player_tackle_prob->setText( QString::fromAscii( buf ) );
+
+        //
+        // foul prob
+        //
+        double foul_fail_prob = 1.0;
+        if ( tackle_dist > 1.0e-5 )
+        {
+            foul_fail_prob = ( std::pow( std::fabs( player_to_ball.x ) / tackle_dist,
+                                         SP.foulExponent() )
+                               + std::pow( player_to_ball.absY() / SP.tackleWidth(),
+                                             SP.foulExponent() ) );
+            foul_fail_prob = std::min( std::max( 0.0, foul_fail_prob ), 1.0 );
+        }
+
+        snprintf( buf, 64, " %.4f", 1.0 - foul_fail_prob );
+        M_player_foul_prob->setText( QString::fromAscii( buf ) );
+
+    }
+
     // pointto point
     if ( player.isPointing() )
     {
