@@ -51,6 +51,7 @@ class QMenu;
 class QMouseEvent;
 class QPaintEvent;
 class QPixmap;
+class QPoint;
 class QPointF;
 class QTimer;
 
@@ -81,7 +82,7 @@ private:
 
     //! 0: left, 1: middle, 2: right
     MouseState M_mouse_state[3];
-    QPoint M_measure_ball_speed_point;
+    QPoint M_measure_first_length_point;
 
     QTimer * M_cursor_timer;
 
@@ -114,6 +115,15 @@ public:
 private:
 
     void drawMouseMeasure( QPainter & painter );
+    void createBallMovePath( const QPoint & start_point,
+                             const QPoint & end_point,
+                             QPainterPath & mark_path,
+                             QPainterPath & text_path );
+    void createPlayerMovePath( const QPoint & start_point,
+                               const QPoint & end_point,
+                               QPainterPath & mark_path,
+                               QPainterPath & text_path );
+
     void drawDraggedPlayer( QPainter & painter );
 
     void grabPlayer( const QPoint & point );
