@@ -32,12 +32,14 @@
 #ifndef SOCCERWINDOW2_QT4_FONT_SETTING_DIALOG_H
 #define SOCCERWINDOW2_QT4_FONT_SETTING_DIALOG_H
 
-#include <rcsc/types.h>
-
 #include <QDialog>
 #include <QFont>
 #include <QPushButton>
 
+#include <rcsc/types.h>
+
+#include <boost/function.hpp>
+
 #include <vector>
 
 class FontButton;
@@ -48,18 +50,23 @@ class FontButton
 
     Q_OBJECT
 
+public:
+
+    typedef boost::function< void ( const QFont & ) > Func;
+
 private:
     QString M_name;
-    QFont M_default_font;
-    QFont * M_font;
+    QFont M_old_font;
+    Func M_func;
 
 public:
 
     FontButton( const QString & name,
-                QFont * font,
+                const QFont & old_font,
+                Func func,
                 FontSettingDialog * parent );
 
-    void setFont( const QFont & font );
+    void setNewFont( const QFont & font );
 
     void revert();
     void updateText();
