@@ -470,6 +470,41 @@ MonitorClient::sendDiscard( const rcsc::SideID side,
     sendCommand( com );
 }
 
+/*-------------------------------------------------------------------*/
+/*!
+
+*/
+void
+MonitorClient::sendCard( const rcsc::SideID side,
+                         const int unum,
+                         const rcsc::Card card )
+{
+    if ( side == rcsc::NEUTRAL )
+    {
+        std::cerr << __FILE__ << ":" << __LINE__
+                  << " dispcard invalid side" << std::endl;
+        return;
+    }
+
+    if ( unum < 1 || 11 < unum )
+    {
+        std::cerr << __FILE__ << ":" << __LINE__
+                  << " dispcard invalid unum " << unum << std::endl;
+        return;
+    }
+
+    if ( card != rcsc::YELLOW
+         && card != rcsc::RED )
+    {
+        std::cerr << __FILE__ << ":" << __LINE__
+                  << " dispcard invalid card " << card << std::endl;
+        return;
+    }
+
+    rcsc::MonitorCardCommand com( side, unum, card );
+
+    sendCommand( com );
+}
 
 /*-------------------------------------------------------------------*/
 /*!
