@@ -102,7 +102,8 @@ PlayerControlPainter::draw( QPainter & painter )
     {
         double max_kick_accel
             = SP.maxPower()
-            * SP.kickPowerRate()
+            //* SP.kickPowerRate()
+            * ptype.kickPowerRate()
             * ( 1.0 - 0.25 * player_to_ball.th().abs() / 180.0
                 - 0.25
                 * ( ball_dist - ptype.playerSize() - SP.ballSize() )
@@ -113,18 +114,18 @@ PlayerControlPainter::draw( QPainter & painter )
             max_kick_accel = SP.ballAccelMax();
         }
 
-        QPoint bpos_screen( opt.screenX( bpos.x ),
-                            opt.screenY( bpos.y ) );
-        QPoint bnext_screen( opt.screenX( bnext.x ),
-                             opt.screenY( bnext.y ) );
-        int max_speed_screen = opt.scale( SP.ballSpeedMax() );
-        int max_kick_accel_screen = opt.scale( max_kick_accel );
+        QPointF bpos_screen( opt.screenXF( bpos.x ),
+                             opt.screenYF( bpos.y ) );
+        QPointF bnext_screen( opt.screenXF( bnext.x ),
+                              opt.screenYF( bnext.y ) );
+        double max_speed_screen = opt.scaleF( SP.ballSpeedMax() );
+        double max_kick_accel_screen = opt.scaleF( max_kick_accel );
 
         painter.setPen( dconf.kickAccelPen() );
         painter.setBrush( dconf.transparentBrush() );
 
         // draw no noise next ball move only by inertia
-        painter.drawLine( bpos_screen, bnext_screen );
+        painter.drawLine( QLineF( bpos_screen, bnext_screen ) );
 
         rcsc::Circle2D max_speed_circle( bpos, SP.ballSpeedMax() );
         rcsc::Circle2D max_accel_circle( bnext, max_kick_accel );
@@ -138,10 +139,10 @@ PlayerControlPainter::draw( QPainter & painter )
             // no intersection points
 
             // just draw a next ball reachable area by max accel
-            painter.drawEllipse( bnext_screen.x() - max_kick_accel_screen,
-                                 bnext_screen.y() - max_kick_accel_screen,
-                                 max_kick_accel_screen * 2,
-                                 max_kick_accel_screen * 2 );
+            painter.drawEllipse( QRectF( bnext_screen.x() - max_kick_accel_screen,
+                                         bnext_screen.y() - max_kick_accel_screen,
+                                         max_kick_accel_screen * 2,
+                                         max_kick_accel_screen * 2 ) );
         }
         else
         {
@@ -184,10 +185,10 @@ PlayerControlPainter::draw( QPainter & painter )
                 = static_cast< int >( rint( - bpos_start_angle->degree() * 16 ) );
             int bpos_angle_span_int
                 = static_cast< int >( rint( bpos_angle_span * 16 ) );
-            painter.drawArc( bpos_screen.x() - max_speed_screen,
-                             bpos_screen.y() - max_speed_screen,
-                             max_speed_screen * 2,
-                             max_speed_screen * 2,
+            painter.drawArc( QRectF( bpos_screen.x() - max_speed_screen,
+                                     bpos_screen.y() - max_speed_screen,
+                                     max_speed_screen * 2,
+                                     max_speed_screen * 2 ),
                              bpos_start_angle_int,
                              bpos_angle_span_int  );
 
@@ -228,10 +229,10 @@ PlayerControlPainter::draw( QPainter & painter )
                 = static_cast< int >( rint( - bnext_start_angle->degree() * 16 ) );
             int bnext_angle_span_int
                 = static_cast< int >( rint( bnext_angle_span * 16 ) );
-            painter.drawArc( bnext_screen.x() - max_kick_accel_screen,
-                             bnext_screen.y() - max_kick_accel_screen,
-                             max_kick_accel_screen * 2,
-                             max_kick_accel_screen * 2,
+            painter.drawArc( QRectF( bnext_screen.x() - max_kick_accel_screen,
+                                     bnext_screen.y() - max_kick_accel_screen,
+                                     max_kick_accel_screen * 2,
+                                     max_kick_accel_screen * 2 ),
                              bnext_start_angle_int,
                              bnext_angle_span_int );
         }
@@ -241,8 +242,8 @@ PlayerControlPainter::draw( QPainter & painter )
         painter.setPen( dconf.kickAccelPen() );
 
         //snprintf( buf, 32, "MaxAccel=%.3f", max_kick_accel );
-        painter.drawText( bnext_screen.x() + 10,
-                          bnext_screen.y() + painter.fontMetrics().ascent(),
+        painter.drawText( QPointF( bnext_screen.x() + 10,
+                                   bnext_screen.y() + painter.fontMetrics().ascent() ),
                           QString( "MaxAccel=%1" ).arg( max_kick_accel, 0, 'g', 4 ) );
     }
 }
