@@ -171,7 +171,7 @@ PlayerPainter::drawAll( QPainter & painter,
 {
     const Options & opt = Options::instance();
 
-    const bool selected = opt.isSelectedPlayer( player.side(), player.unum() );
+    const bool selected = opt.isSelectedAgent( player.side(), player.unum() );
     const Param param( player,
                        ball,
                        M_main_data.viewHolder().playerType( player.type() ) );
@@ -643,8 +643,8 @@ PlayerPainter::drawViewArea( QPainter & painter,
     const double view_start_angle = -param.head_ - view_width * 0.5;
 
     // draw enlarged view cone and feel area
-    if ( opt.isSelectedPlayer( param.player_.side(),
-                               param.player_.unum() ) )
+    if ( opt.isSelectedAgent( param.player_.side(),
+                              param.player_.unum() ) )
     {
         const double UNUM_FAR = opt.scaleF( 20.0 );
         const double TEAM_FAR = opt.scaleF( 40.0 );
@@ -1319,8 +1319,8 @@ PlayerPainter::drawText( QPainter & painter,
         if ( ! str.isEmpty() )
         {
             // this player is selected
-            if ( opt.isSelectedPlayer( param.player_.side(),
-                                       param.player_.unum() ) )
+            if ( opt.isSelectedAgent( param.player_.side(),
+                                      param.player_.unum() ) )
             {
                 str += QString( ",e%1,r%2" )
                     .arg( param.player_.effort(), 0, 'g', 3 )
