@@ -35,6 +35,7 @@
 #include <QDialog>
 
 class QAbstractItemModel;
+class QModelIndex;
 class QShowEvent;
 class QStandardItemModel;
 class QTableView;
@@ -81,6 +82,10 @@ public slots:
 
     void updateData();
 
+private slots:
+
+    void handleDoubleClick( const QModelIndex & index );
+
 };
 
 #endif
