@@ -260,50 +260,50 @@ ScoreBoardPainter::drawPenaltyScores( QPainter & painter )
     }
     if ( score_size < 5 ) score_size = 5;
 
-    int board_left_x
+    double board_left_x
         = ( left_goal
-            ? opt.absScreenX( 1.0 )
-            : opt.absScreenX( -1.0 ) - cell_size*score_size - name_width );
-    int board_top_y = opt.absScreenY( 17.0 );
+            ? opt.absScreenXF( 1.0 )
+            : opt.absScreenXF( -1.0 ) - cell_size*score_size - name_width );
+    double board_top_y = opt.absScreenYF( 17.0 );
 
-    int board_width = name_width + cell_size*score_size;
-    int board_height = cell_size*3;
+    double board_width = name_width + cell_size*score_size;
+    double board_height = cell_size*3;
 
     //int board_right_x = board_left_x + board_width;
-    int board_bottom_y = board_top_y + board_height;
+    double board_bottom_y = board_top_y + board_height;
 
-    painter.fillRect( board_left_x, board_top_y,
-                      board_width, board_height,
+    painter.fillRect( QRectF( board_left_x, board_top_y,
+                              board_width, board_height ),
                       Qt::white );
 
-    painter.fillRect( board_left_x, board_top_y + cell_size,
-                      board_width, cell_size,
+    painter.fillRect( QRectF( board_left_x, board_top_y + cell_size,
+                              board_width, cell_size ),
                       dconf.leftTeamBrush() );
-    painter.fillRect( board_left_x, board_top_y + cell_size*2,
-                      board_width, cell_size,
+    painter.fillRect( QRectF( board_left_x, board_top_y + cell_size*2,
+                              board_width, cell_size ),
                       dconf.rightTeamBrush() );
 
-    painter.drawText( board_left_x, board_top_y + cell_size,
-                      name_width, cell_size,
+    painter.drawText( QRectF( board_left_x, board_top_y + cell_size,
+                              name_width, cell_size ),
                       Qt::AlignCenter,
                       QObject::tr( "left" ) );
-    painter.drawText( board_left_x, board_top_y + cell_size*2,
-                      name_width, cell_size,
+    painter.drawText( QRectF( board_left_x, board_top_y + cell_size*2,
+                              name_width, cell_size ),
                       Qt::AlignCenter,
                       QObject::tr( "right" ) );
 
-    painter.drawLine( board_left_x + name_width, board_top_y,
-                      board_left_x + name_width, board_bottom_y );
+    painter.drawLine( QLineF( board_left_x + name_width, board_top_y,
+                              board_left_x + name_width, board_bottom_y ) );
 
     for ( int i = 1; i <= score_size; ++i )
     {
-        int line_x = board_left_x + name_width + cell_size*i;
-        painter.drawText( line_x - cell_size, board_top_y,
-                          cell_size, cell_size,
+        double line_x = board_left_x + name_width + cell_size*i;
+        painter.drawText( QRectF( line_x - cell_size, board_top_y,
+                                  cell_size, cell_size ),
                           Qt::AlignCenter,
                           QString::number( i ) );
-        painter.drawLine( line_x, board_top_y,
-                          line_x, board_bottom_y );
+        painter.drawLine( QLineF( line_x, board_top_y,
+                                 line_x, board_bottom_y ) );
     }
 
     int idx = 0;
@@ -313,22 +313,22 @@ ScoreBoardPainter::drawPenaltyScores( QPainter & painter )
     {
         if ( it->first > view->cycle() ) break;
 
-        int row_x = board_left_x + name_width + cell_size*idx;
+        double row_x = board_left_x + name_width + cell_size*idx;
         if ( it->second == rcsc::PM_PenaltyScore_Left
              || it->second == rcsc::PM_PenaltyScore_Right )
         {
-            painter.drawEllipse( row_x + 4,
-                                 board_top_y + cell_size + 4,
-                                 cell_size-6,
-                                 cell_size-6 );
+            painter.drawEllipse( QRectF( row_x + 4,
+                                         board_top_y + cell_size + 4,
+                                         cell_size-6,
+                                         cell_size-6 ) );
         }
         else if ( it->second == rcsc::PM_PenaltyMiss_Left
                   || it->second == rcsc::PM_PenaltyMiss_Right )
         {
-            painter.drawLine( row_x + 4, board_top_y + cell_size + 4,
-                              row_x + cell_size - 4, board_top_y + cell_size*2 - 4 );
-            painter.drawLine( row_x + cell_size - 4, board_top_y + cell_size + 4,
-                              row_x + 4, board_top_y + cell_size*2 - 4 );
+            painter.drawLine( QLineF( row_x + 4, board_top_y + cell_size + 4,
+                                      row_x + cell_size - 4, board_top_y + cell_size*2 - 4 ) );
+            painter.drawLine( QLineF( row_x + cell_size - 4, board_top_y + cell_size + 4,
+                                      row_x + 4, board_top_y + cell_size*2 - 4 ) );
         }
 
         ++idx;
@@ -341,22 +341,22 @@ ScoreBoardPainter::drawPenaltyScores( QPainter & painter )
     {
         if ( it->first > view->cycle() ) break;
 
-        int row_x = board_left_x + name_width + cell_size*idx;
+        double row_x = board_left_x + name_width + cell_size*idx;
         if ( it->second == rcsc::PM_PenaltyScore_Left
              || it->second == rcsc::PM_PenaltyScore_Right )
         {
-            painter.drawEllipse( row_x + 4,
-                                 board_top_y + cell_size*2 + 4,
-                                 cell_size-6,
-                                 cell_size-6 );
+            painter.drawEllipse( QRectF( row_x + 4,
+                                         board_top_y + cell_size*2 + 4,
+                                         cell_size-6,
+                                         cell_size-6 ) );
         }
         else if ( it->second == rcsc::PM_PenaltyMiss_Left
                   || it->second == rcsc::PM_PenaltyMiss_Right )
         {
-            painter.drawLine( row_x + 4, board_top_y + cell_size*2 + 4,
-                              row_x + cell_size - 4, board_top_y + cell_size*3 - 4 );
-            painter.drawLine( row_x + cell_size - 4, board_top_y + cell_size*2 + 4,
-                              row_x + 4, board_top_y + cell_size*3 - 4 );
+            painter.drawLine( QLineF( row_x + 4, board_top_y + cell_size*2 + 4,
+                                      row_x + cell_size - 4, board_top_y + cell_size*3 - 4 ) );
+            painter.drawLine( QLineF( row_x + cell_size - 4, board_top_y + cell_size*2 + 4,
+                                      row_x + 4, board_top_y + cell_size*3 - 4 ) );
         }
 
         ++idx;
