@@ -48,12 +48,14 @@
 #include <rcsc/geom/voronoi_diagram.h>
 #include <rcsc/geom/delaunay_triangulation.h>
 #include <rcsc/geom/triangulation.h>
+#ifndef NO_TIMER
 #include <rcsc/timer.h>
+#endif
 
 /*-------------------------------------------------------------------*/
 /*!
 
-*/
+ */
 namespace  {
 
 /*!
@@ -84,7 +86,7 @@ struct VoronoiEdge {
 /*-------------------------------------------------------------------*/
 /*!
 
-*/
+ */
 void
 VoronoiDiagramPainter::draw( QPainter & painter )
 {
@@ -146,19 +148,18 @@ VoronoiDiagramPainter::draw( QPainter & painter )
 /*-------------------------------------------------------------------*/
 /*!
 
-*/
+ */
 void
 VoronoiDiagramPainter::drawVoronoiDiagram( QPainter & painter,
                                            const std::vector< rcsc::Vector2D > & players )
 {
     const Options & opt = Options::instance();
 
-   const rcsc::Rect2D PITCH_RECT( rcsc::Vector2D( - rcsc::ServerParam::i().pitchHalfLength(),
+    const rcsc::Rect2D PITCH_RECT( rcsc::Vector2D( - rcsc::ServerParam::i().pitchHalfLength(),
                                                    - rcsc::ServerParam::i().pitchHalfWidth() ),
                                    rcsc::Size2D( rcsc::ServerParam::i().pitchLength(),
                                                  rcsc::ServerParam::i().pitchWidth() ) );
-
-    rcsc::Timer timer;
+    //rcsc::Timer timer;
     rcsc::VoronoiDiagram voronoi( players );
     voronoi.setBoundingRect( PITCH_RECT );
     voronoi.compute();
@@ -179,34 +180,34 @@ VoronoiDiagramPainter::drawVoronoiDiagram( QPainter & painter,
         int n = PITCH_RECT.intersection( *s, &pos1, &pos2 );
         if ( n == 2 )
         {
-            path.moveTo( opt.absScreenX( pos1.x ),
-                         opt.absScreenY( pos1.y ) );
-            path.lineTo( opt.absScreenX( pos2.x ),
-                         opt.absScreenY( pos2.y ) );
+            path.moveTo( opt.absScreenXF( pos1.x ),
+                         opt.absScreenYF( pos1.y ) );
+            path.lineTo( opt.absScreenXF( pos2.x ),
+                         opt.absScreenYF( pos2.y ) );
         }
         else if ( n == 1 )
         {
             if ( PITCH_RECT.contains( s->origin() ) )
             {
-                path.moveTo( opt.absScreenX( s->origin().x ),
-                             opt.absScreenY( s->origin().y ) );
-                path.lineTo( opt.absScreenX( pos1.x ),
-                             opt.absScreenY( pos1.y ) );
+                path.moveTo( opt.absScreenXF( s->origin().x ),
+                             opt.absScreenYF( s->origin().y ) );
+                path.lineTo( opt.absScreenXF( pos1.x ),
+                             opt.absScreenYF( pos1.y ) );
             }
             else
             {
-                path.moveTo( opt.absScreenX( s->terminal().x ),
-                             opt.absScreenY( s->terminal().y ) );
-                path.lineTo( opt.absScreenX( pos1.x ),
-                             opt.absScreenY( pos1.y ) );
+                path.moveTo( opt.absScreenXF( s->terminal().x ),
+                             opt.absScreenYF( s->terminal().y ) );
+                path.lineTo( opt.absScreenXF( pos1.x ),
+                             opt.absScreenYF( pos1.y ) );
             }
         }
         else if ( PITCH_RECT.contains( s->origin() ) )
         {
-            path.moveTo( opt.absScreenX( s->origin().x ),
-                         opt.absScreenY( s->origin().y ) );
-            path.lineTo( opt.absScreenX( s->terminal().x ),
-                         opt.absScreenY( s->terminal().y ) );
+            path.moveTo( opt.absScreenXF( s->origin().x ),
+                         opt.absScreenYF( s->origin().y ) );
+            path.lineTo( opt.absScreenXF( s->terminal().x ),
+                         opt.absScreenYF( s->terminal().y ) );
         }
     }
 
@@ -219,10 +220,10 @@ VoronoiDiagramPainter::drawVoronoiDiagram( QPainter & painter,
         rcsc::Vector2D pos;
         if ( PITCH_RECT.intersection( *r, &pos, static_cast< rcsc::Vector2D * >( 0 ) ) == 1 )
         {
-            path.moveTo( opt.absScreenX( r->origin().x ),
-                         opt.absScreenY( r->origin().y ) );
-            path.lineTo( opt.absScreenX( pos.x ),
-                         opt.absScreenY( pos.y ) );
+            path.moveTo( opt.absScreenXF( r->origin().x ),
+                         opt.absScreenYF( r->origin().y ) );
+            path.lineTo( opt.absScreenXF( pos.x ),
+                         opt.absScreenYF( pos.y ) );
         }
     }
 #endif
@@ -233,7 +234,7 @@ VoronoiDiagramPainter::drawVoronoiDiagram( QPainter & painter,
 /*-------------------------------------------------------------------*/
 /*!
 
-*/
+ */
 void
 VoronoiDiagramPainter::drawDelaunayTriangulation( QPainter & painter,
                                                   const std::vector< rcsc::Vector2D > & players )
@@ -287,10 +288,10 @@ VoronoiDiagramPainter::drawDelaunayTriangulation( QPainter & painter,
           e != e_end;
           ++e )
     {
-        path.moveTo( opt.absScreenX( points[e->first].x ),
-                     opt.absScreenY( points[e->first].y ) );
-        path.lineTo( opt.absScreenX( points[e->second].x ),
-                     opt.absScreenY( points[e->second].y ) );
+        path.moveTo( opt.absScreenXF( points[e->first].x ),
+                     opt.absScreenYF( points[e->first].y ) );
+        path.lineTo( opt.absScreenXF( points[e->second].x ),
+                     opt.absScreenYF( points[e->second].y ) );
     }
 
     painter.drawPath( path );
@@ -300,7 +301,7 @@ VoronoiDiagramPainter::drawDelaunayTriangulation( QPainter & painter,
 /*-------------------------------------------------------------------*/
 /*!
 
-*/
+ */
 void
 VoronoiDiagramPainter::drawOld( QPainter & painter )
 {
@@ -329,7 +330,7 @@ VoronoiDiagramPainter::drawOld( QPainter & painter )
         return;
     }
 
-    //rcsc::MSecTimer timer;
+    //rcsc::Timer timer;
     //timer.restart();
 
     std::vector< rcsc::Vector2D > players_pos;
@@ -362,12 +363,13 @@ VoronoiDiagramPainter::drawOld( QPainter & painter )
 
     if ( opt.antiAliasing() )
     {
-        painter.setRenderHints(
-#ifdef USE_GLWIDGET
-                               //QPainter::HighQualityAntialiasing |
+#ifdef USE_HIGH_QUALITY_ANTIALIASING
+        painter.setRenderHints( QPainter::HighQualityAntialiasing |
+                                QPainter::Antialiasing,
+                                false );
+#else
+        painter.setRenderHint( QPainter::Antialiasing, false );
 #endif
-                               QPainter::Antialiasing,
-                               false );
     }
 
     std::vector< rcsc::Vector2D > segment_points;
@@ -401,7 +403,7 @@ VoronoiDiagramPainter::drawOld( QPainter & painter )
                                                             players_pos[k] );
                 rcsc::Vector2D perpend_intersect
                     = rcsc::Line2D::intersection( first_perpend, k_perpend );
-                if ( ! perpend_intersect.valid() )
+                if ( ! perpend_intersect.isValid() )
                 {
                     continue; // intersection does not exist
                 }
@@ -512,10 +514,10 @@ VoronoiDiagramPainter::drawOld( QPainter & painter )
               it != end;
               ++it )
         {
-            path.moveTo( opt.absScreenX( (*it)->point1.x ),
-                         opt.absScreenY( (*it)->point1.y ) );
-            path.lineTo( opt.absScreenX( (*it)->point2.x ),
-                         opt.absScreenY( (*it)->point2.y ) );
+            path.moveTo( opt.absScreenXF( (*it)->point1.x ),
+                         opt.absScreenYF( (*it)->point1.y ) );
+            path.lineTo( opt.absScreenXF( (*it)->point2.x ),
+                         opt.absScreenYF( (*it)->point2.y ) );
         }
 
         painter.drawPath( path );
@@ -532,10 +534,10 @@ VoronoiDiagramPainter::drawOld( QPainter & painter )
               it != end;
               ++it )
         {
-            path.moveTo( opt.absScreenX( players_pos[(*it)->player1].x ),
-                         opt.absScreenY( players_pos[(*it)->player1].y ) );
-            path.lineTo( opt.absScreenX( players_pos[(*it)->player2].x ),
-                         opt.absScreenY( players_pos[(*it)->player2].y ) );
+            path.moveTo( opt.absScreenXF( players_pos[(*it)->player1].x ),
+                         opt.absScreenYF( players_pos[(*it)->player1].y ) );
+            path.lineTo( opt.absScreenXF( players_pos[(*it)->player2].x ),
+                         opt.absScreenYF( players_pos[(*it)->player2].y ) );
         }
 
         painter.drawPath( path );
@@ -544,11 +546,12 @@ VoronoiDiagramPainter::drawOld( QPainter & painter )
 
     if ( opt.antiAliasing() )
     {
-        painter.setRenderHints(
-#ifdef USE_GLWIDGET
-                               //QPainter::HighQualityAntialiasing |
+#ifdef USE_HIGH_QUALITY_ANTIALIASING
+        painter.setRenderHints( QPainter::HighQualityAntialiasing |
+                                QPainter::Antialiasing,
+                                true );
+#else
+        painter.setRenderHint( QPainter::Antialiasing, true );
 #endif
-                               QPainter::Antialiasing,
-                               true );
     }
 }
